# coding=utf-8

from django.db import models
from django.utils.translation import ugettext, ugettext_lazy as _


class Message(models.Model):
    phone = models.CharField(verbose_name=_(u'phone number'), max_length=12)
    text = models.TextField(verbose_name=_(u'text'))
    identifier = models.IntegerField(verbose_name=_(u'identifier'))
    status = models.CharField(verbose_name=_(u'status'), max_length=128, blank=True, null=True)
    created = models.DateTimeField(verbose_name=_(u'created'), auto_now_add=True)

    class Meta:
        verbose_name = _(u'message')
        verbose_name_plural = _(u'messages')

    def __unicode__(self):
        return ugettext(u'Message to {0} on {1}').format(self.phone, self.created)



# coding=utf-8

from datetime import timedelta

from django.core.management.base import NoArgsCommand
from django.utils import timezone

from smsaero import models as _models
from smsaero import api as _api


class Command(NoArgsCommand):
    def handle_noargs(self, **options):
        full_day = timezone.now() - timedelta(days=1)
        # выбираем сообщения не старше суток
        messages = _models.Message.objects.filter(created__gt=full_day)
        for message in messages:
            status = _api.get_status(message.identifier)
            message.status = status
            message.save(update_fields=['status'])
        print u'{0} messages have been updated'.format(messages.count())



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Message'
        db.create_table(u'smsaero_message', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('phone', self.gf('django.db.models.fields.CharField')(max_length=12)),
            ('text', self.gf('django.db.models.fields.TextField')()),
            ('identifier', self.gf('django.db.models.fields.IntegerField')()),
            ('status', self.gf('django.db.models.fields.CharField')(max_length=128, null=True, blank=True)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal(u'smsaero', ['Message'])


    def backwards(self, orm):
        # Deleting model 'Message'
        db.delete_table(u'smsaero_message')


    models = {
        u'smsaero.message': {
            'Meta': {'object_name': 'Message'},
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'identifier': ('django.db.models.fields.IntegerField', [], {}),
            'phone': ('django.db.models.fields.CharField', [], {'max_length': '12'}),
            'status': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True', 'blank': 'True'}),
            'text': ('django.db.models.fields.TextField', [], {})
        }
    }

    complete_apps = ['smsaero']


# coding=utf-8

import requests
from hashlib import md5

from smsaero import settings as _settings
from smsaero import exceptions as _exceptions
from smsaero import models as _models


def smsaero_post(url, params):
    data = {
        'answer': 'json',
        'user': _settings.USER,
        'password': md5(_settings.PASSWORD).hexdigest(),
        'from': _settings.SIGNATURE,
    }
    data.update(params)
    response = requests.post(url, data=data)
    answer = response.json()
    return answer


def send_sms(phone, text):
    params = {
        'to': phone,
        'text': text,
    }
    answer = smsaero_post(_settings.SEND_URL, params)
    if answer['result'] != 'accepted':
        raise _exceptions.SMSAeroException(answer)
    _models.Message.objects.create(phone=phone, text=text, identifier=answer['id'])


def get_status(identifier):
    params = {
        'id': identifier,
    }
    answer = smsaero_post(_settings.STATUS_URL, params)
    if answer['result'] == 'reject':
        return answer['reason']
    return answer['result']



# coding=utf-8

from django.conf import settings


SEND_URL = getattr(settings, 'SMSAERO_SEND_URL', 'https://gate.smsaero.ru/send/')
STATUS_URL = getattr(settings, 'SMSAERO_STATUS_URL', 'https://gate.smsaero.ru/status/')

USER = getattr(settings, 'SMSAERO_USER', '')
PASSWORD = getattr(settings, 'SMSAERO_PASSWORD', '')
SIGNATURE = getattr(settings, 'SMSAERO_SIGNATURE', '')



# coding=utf-8

from django.contrib import admin

from smsaero import models as _models


class MessageAdmin(admin.ModelAdmin):
    list_display = ('phone', 'text', 'identifier', 'status', 'created')
    search_fields = ('phone', 'text', 'identifier')
    list_filter = ('status',)
    fields = ('phone', 'text', 'identifier', 'status', 'created')
    readonly_fields = ('phone', 'text', 'identifier', 'status', 'created')


admin.site.register(_models.Message, MessageAdmin)
